#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-conversions
version:              0.3.1
visibility:           public
id:                   text-conversions-0.3.1-7hGIKASOmbJBE4EoFyw2z8
key:                  text-conversions-0.3.1-7hGIKASOmbJBE4EoFyw2z8
license:              ISC
maintainer:           lexi.lambda@gmail.com
author:               Alexis King
homepage:             https://github.com/cjdev/text-conversions#readme
synopsis:             Safe conversions between textual types
description:          Safe conversions between textual types
category:             Data
abi:                  9c644a5cbe90b6b203d9bd7d5646a6af
exposed:              True
exposed-modules:      Data.Text.Conversions
hidden-modules:       Paths_text_conversions
import-dirs:          /usr/lib/ghc-8.10.5/site-local/text-conversions-0.3.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/text-conversions-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/text-conversions-0.3.1
hs-libraries:         HStext-conversions-0.3.1-7hGIKASOmbJBE4EoFyw2z8
depends:
    base-4.14.2.0 base16-bytestring-1.0.1.0-L8MYVxGxjrHE5OI1p1aFGq
    base64-bytestring-1.2.0.1-Gn2QlQL7quxDmGBEoLUsKs
    bytestring-0.10.12.0 errors-2.3.0-L2PYtE6sWhcKjNVUy63IeC
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-text-conversions/html/text-conversions.haddock

haddock-html:         /usr/share/doc/haskell-text-conversions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

